==> gkola-0.1.38.tar.gz: gkola-0.1.38/gkola/app.py <==
# -*- coding: utf-8 -*-

import functools
import gevent
from gevent.server import StreamServer
import kola
from kola import safe_call, safe_func
from .connection import Connection
from netstream import NetStream


class Kola(kola.Kola):

    server = None

    def __init__(self, server_class=None, conn_class=None):
        super(Kola, self).__init__()
        self.server_class = server_class or StreamServer
        self.conn_class = conn_class or Connection

    def handle_stream(self, sock, address):
        self.conn_class(self, NetStream(sock), address).process()

    def run(self, host, port, patch_all=True):
        if patch_all:
            from gevent import monkey
            monkey.patch_all()

        self.server = self.server_class((host, port), self.handle_stream)

        self._start_repeat_timers()
        self.server.serve_forever()

    def register_blueprint(self, blueprint):
        blueprint.register2app(self)

    def repeat_timer(self, interval):
        """
        每隔一段时间执行(秒)
        """
        def inner_repeat_timer(func):
            @functools.wraps(func)
            def func_wrapper(*args, **kwargs):
                # 每次也要再加入

                result = safe_call(func, *args, **kwargs)
                gevent.spawn_later(interval, func_wrapper)

                return result

            self.events.repeat_timer += functools.partial(gevent.spawn_later, interval, func_wrapper)
            return func_wrapper
        return inner_repeat_timer

    def _start_repeat_timers(self):
        """
        把那些repeat timers启动
        """
        self.events.repeat_timer()
        for name, bp in self.blueprints.items():
            bp.events.repeat_app_timer()

==> gkola-0.1.39.tar.gz: gkola-0.1.39/gkola/app.py <==
# -*- coding: utf-8 -*-

import functools
import gevent
from gevent.server import StreamServer
import kola
from kola import safe_call, safe_func
from .connection import Connection
from netkit.stream import Stream


class Kola(kola.Kola):

    server = None

    def __init__(self, server_class=None, conn_class=None):
        super(Kola, self).__init__()
        self.server_class = server_class or StreamServer
        self.conn_class = conn_class or Connection

    def handle_stream(self, sock, address):
        self.conn_class(self, Stream(sock), address).process()

    def run(self, host, port, patch_all=True):
        if patch_all:
            from gevent import monkey
            monkey.patch_all()

        self.server = self.server_class((host, port), self.handle_stream)

        self._start_repeat_timers()
        self.server.serve_forever()

    def register_blueprint(self, blueprint):
        blueprint.register2app(self)

    def repeat_timer(self, interval):
        """
        每隔一段时间执行(秒)
        """
        def inner_repeat_timer(func):
            @functools.wraps(func)
            def func_wrapper(*args, **kwargs):
                # 每次也要再加入

                result = safe_call(func, *args, **kwargs)
                gevent.spawn_later(interval, func_wrapper)

                return result

            self.events.repeat_timer += functools.partial(gevent.spawn_later, interval, func_wrapper)
            return func_wrapper
        return inner_repeat_timer

    def _start_repeat_timers(self):
        """
        把那些repeat timers启动
        """
        self.events.repeat_timer()
        for name, bp in self.blueprints.items():
            bp.events.repeat_app_timer()
